#
#  -------------------------------------------------------------------------
#  MIT License
#  
#  Copyright (c) 2024 Randy
#  
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#  
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#  
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
#  -------------------------------------------------------------------------
#
#  this module is imported by ns4decode.py
#
#  this module provides several static dictionaries
#  for converting indexes to names
#
#  this module also provides the getNames() function, 
#  which converts (what I assume are) hashes to sample names
#
from os import path as ospath
from sys import exit

nameFilenames = {}
nameFilenames['piano_models'] = 'ns4decode_piano_models.txt'
nameFilenames['sample_names'] = 'ns4decode_sample_names.txt'

OnOff = {}
OnOff[0] = 'off'
OnOff[1] = 'on'

IncludeExclude = {}
IncludeExclude[0] = 'exclude'
IncludeExclude[1] = 'include'

Letter = {}
Letter[0] = 'A'
Letter[1] = 'B'
Letter[2] = 'C'
Letter[3] = 'D'
Letter[4] = 'E'
Letter[5] = 'F'
Letter[6] = 'G'
Letter[7] = 'H'

Sections = {}
Sections[0] = 'organ'
Sections[1] = 'piano'
Sections[2] = 'synth'

SampleAnalog = {}
SampleAnalog[0] = 'samples'
SampleAnalog[1] = 'analog'

LayerScene = {}
LayerScene[0] = 'I'
LayerScene[1] = 'II'

# for SplitZones:
#
# using "o" instead of "0" so the spreadsheet app formats it as text instead of as a number
#
# in SplitZones[j][k], 
#       j is a 3-bit number whose bits say which split-points are on/off
#       k is the rawval of the given layer's KB zone parameter
SplitZones = {}
SplitZones[0b000] = ['1111', '1111', '1111', '1111', '1111', '1111', '1111', '1111', '1111', '1111', '1111']
SplitZones[0b001] = ['111o', '111o', '111o', '111o', '111o', '1111', 'ooo1', 'ooo1', 'ooo1', 'ooo1', 'ooo1'] # 111o and ooo1
SplitZones[0b010] = ['11oo', '11oo', '11oo', '11oo', '11oo', '1111', 'oo11', 'oo11', 'oo11', 'oo11', 'oo11'] # 11oo and oo11
SplitZones[0b011] = ['11oo', 'oo1o', '111o', '111o', '111o', '1111', 'oo11', 'oo11', 'oo11', 'oo1o', 'ooo1'] # 11oo and oo1o and ooo1
SplitZones[0b100] = ['1ooo', '1ooo', '1ooo', '1ooo', '1ooo', '1111', 'o111', 'o111', 'o111', 'o111', 'o111'] # 1ooo and o111
SplitZones[0b101] = ['1ooo', 'o11o', '111o', '111o', '111o', '1111', 'o111', 'o111', 'o111', 'o11o', 'ooo1'] # 1ooo and o11o and ooo1
SplitZones[0b110] = ['1ooo', 'o1oo', '11oo', '11oo', '11oo', '1111', 'o111', 'o111', 'o111', 'o1oo', 'oo11'] # 1ooo and o1oo and oo11
SplitZones[0b111] = ['1ooo', 'o1oo', '11oo', 'o11o', '111o', '1111', 'o111', 'o11o', 'oo11', 'oo1o', 'ooo1']

SplitZoneXfade = {}
SplitZoneXfade[0] = 'none'
SplitZoneXfade[1] = '+/- 6 semitones'
SplitZoneXfade[2] = '+/- 12 semitones'

SplitPoint = {} # the indicated note is on the high side of the split point
SplitPoint[ 0] = 'C2'
SplitPoint[ 1] = 'F2'
SplitPoint[ 2] = 'C3'
SplitPoint[ 3] = 'F3'
SplitPoint[ 4] = 'C4'
SplitPoint[ 5] = 'F4'
SplitPoint[ 6] = 'C5'
SplitPoint[ 7] = 'F5'
SplitPoint[ 8] = 'C6'
SplitPoint[ 9] = 'F6'
SplitPoint[10] = 'C7'

OctaveShift = {}
OctaveShift[0] = '0'
OctaveShift[1] = '+1'
OctaveShift[2] = '+2'
OctaveShift[16-1] = '-1'
OctaveShift[16-2] = '-2'

OrganVibChorusType = {}
OrganVibChorusType['B3'] = {}
OrganVibChorusType['B3'][0] = 'V1'
OrganVibChorusType['B3'][1] = 'C1'
OrganVibChorusType['B3'][2] = 'V2'
OrganVibChorusType['B3'][3] = 'C2'
OrganVibChorusType['B3'][4] = 'V3'
OrganVibChorusType['B3'][5] = 'C3'
OrganVibChorusType['VOX'] = {}
OrganVibChorusType['VOX'][0] = 'V1'
OrganVibChorusType['VOX'][1] = 'V2'
OrganVibChorusType['VOX'][2] = 'V3'
OrganVibChorusType['FARF'] = {}
OrganVibChorusType['FARF'][0] = 'V1'
OrganVibChorusType['FARF'][1] = 'V2'
OrganVibChorusType['FARF'][2] = 'C2'
OrganVibChorusType['FARF'][3] = 'C3'
OrganVibChorusType['PIPE'] = 'C1'

OrganModel = {}
OrganModel[0] = 'B3'
OrganModel[1] = 'VOX'
OrganModel[2] = 'FARF'
OrganModel[3] = 'PIPE1'
OrganModel[4] = 'PIPE2'
OrganModel[5] = 'B3 BASS'

VoxDrawbar9 = {}
VoxDrawbar9[0] = '1'
VoxDrawbar9[1] = '2'
VoxDrawbar9[2] = '3'
VoxDrawbar9[3] = '4'
VoxDrawbar9[4] = '4+5'
VoxDrawbar9[5] = '5'
VoxDrawbar9[6] = '6'
VoxDrawbar9[7] = '7'
VoxDrawbar9[8] = '8'

RotarySpeed = {}
RotarySpeed[0] = 'slow'
RotarySpeed[1] = 'fast'

RotaryStopPosition = {}
RotaryStopPosition[0] = 'Free'
RotaryStopPosition[1] = 'Front Center'
RotaryStopPosition[2] = 'Front Left'
RotaryStopPosition[3] = 'Front Right'
RotaryStopPosition[4] = 'Back Left'
RotaryStopPosition[5] = 'Back Right'
RotaryStopPosition[6] = 'Back Center'

PianoType = {}
PianoType[0] = 'Grand'
PianoType[1] = 'Upright'
PianoType[2] = 'Electric'
PianoType[3] = 'Clav'
PianoType[4] = 'Digital'
PianoType[5] = 'Misc'

ClavVariation = {}
ClavVariation[0] = 'CA'
ClavVariation[1] = 'CB'
ClavVariation[2] = 'DA'
ClavVariation[3] = 'DB'

PianoTouch = {}
PianoTouch[0] = 'heavy'
PianoTouch[1] = 'med'
PianoTouch[2] = 'light'

TimbreAcoustic = {}
TimbreAcoustic[0] = 'off'
TimbreAcoustic[1] = 'SOFT'
TimbreAcoustic[2] = 'MID'
TimbreAcoustic[3] = 'BRIGHT'
TimbreAcoustic[4] = 'off'
TimbreAcoustic[5] = 'SOFT'
TimbreAcoustic[6] = 'MID'
TimbreAcoustic[7] = 'BRIGHT'

TimbreElectric = {}
TimbreElectric[0] = 'off'
TimbreElectric[1] = 'SOFT'
TimbreElectric[2] = 'MID'
TimbreElectric[3] = 'BRIGHT'
TimbreElectric[4] = 'DYNO1'
TimbreElectric[5] = 'DYNO2'
TimbreElectric[6] = 'off'
TimbreElectric[7] = 'SOFT'

TimbreClav = {}
TimbreClav[0] = 'off'
TimbreClav[1] = 'SOFT'
TimbreClav[2] = 'MID'
TimbreClav[3] = 'SOFT+MID'
TimbreClav[4] = 'BRIGHT'
TimbreClav[5] = 'SOFT+BRIGHT'
TimbreClav[6] = 'MID+BRIGHT'
TimbreClav[7] = 'SOFT+MID+BRIGHT'

SynthType = {}
SynthType[0] = 'ANALOG'
SynthType[1] = 'FM-H'
SynthType[2] = 'FM-I'
SynthType[3] = 'WAVE'

SynthCategory = {}
SynthCategory['ANALOG'] = {}
SynthCategory['ANALOG'][0] = 'PURE'
SynthCategory['ANALOG'][1] = 'SUB OSC'  
SynthCategory['ANALOG'][2] = 'SYNC'     
SynthCategory['ANALOG'][3] = 'SHAPE'
SynthCategory['ANALOG'][4] = 'SHAPE SINE'
SynthCategory['ANALOG'][5] = 'MULTI'
SynthCategory['ANALOG'][6] = 'SUPER'
SynthCategory['ANALOG'][7] = 'MISC'     
SynthCategory['WAVE'] = {}
SynthCategory['WAVE'][0] = 'BELLS/TINES'
SynthCategory['WAVE'][1] = 'ACOUSTIC'
SynthCategory['WAVE'][2] = 'DIGITAL'
SynthCategory['WAVE'][3] = 'ORGAN'
SynthCategory['WAVE'][4] = 'KEYS'

SynthCategoryOld = {} # for older file versions
SynthCategoryOld['ANALOG'] = {}
SynthCategoryOld['ANALOG'][0] = 'PURE'
SynthCategoryOld['ANALOG'][1] = 'SHAPE'
SynthCategoryOld['ANALOG'][2] = 'SHAPE SINE'
SynthCategoryOld['ANALOG'][3] = 'MULTI'
SynthCategoryOld['ANALOG'][4] = 'SUPER'
SynthCategoryOld['ANALOG'][5] = 'SYNC'     
SynthCategoryOld['ANALOG'][6] = 'MISC'     
SynthCategoryOld['ANALOG'][7] = 'PURE'

SynthWaveOld = {} # for older file versions
#SynthWaveOld[0] = {}
#SynthWaveOld[0][0] = 'Pure Sine'
#SynthWaveOld[0][1] = 'Pure Triangle' # unconfirmed guess
#SynthWaveOld[0][2] = 'Pure Saw'
#SynthWaveOld[0][3] = 'Pure Square'
#SynthWaveOld[0][4] = 'Pure Pulse 33'
#SynthWaveOld[0][5] = 'Pure Pulse 10'
SynthWaveOld[3] = {}
SynthWaveOld[3][0] = 'Multi Saw 8ve'
SynthWaveOld[3][1] = 'Multi Saw 5th'
SynthWaveOld[3][2] = 'Multi Saw 5th+' # unconfirmed guess
SynthWaveOld[3][3] = 'Multi Saw 8ve 8ve+'
SynthWaveOld[6] = {}
SynthWaveOld[6][0] = 'Bell'
SynthWaveOld[7] = {}
SynthWaveOld[7][0] = 'Pure White Noise'
SynthWaveOld[7][1] = 'Pink Noise'

SynthWave = {}
SynthWave['PURE'] = {}
SynthWave['PURE'][0] = 'Pure Sine'
SynthWave['PURE'][1] = 'Pure Triangle'
SynthWave['PURE'][2] = 'Pure Saw'
SynthWave['PURE'][3] = 'Pure Square'
SynthWave['PURE'][4] = 'Pure Pulse 33'
SynthWave['PURE'][5] = 'Pure Pulse 10'
SynthWave['PURE'][6] = 'Pure White Noise'
SynthWave['SUB OSC'] = {}
SynthWave['SUB OSC'][0] = 'Sub Square Saw'
SynthWave['SUB OSC'][1] = 'Sub Pulse Saw'
SynthWave['SUB OSC'][2] = 'Sub Sine Saw'
SynthWave['SYNC'] = {}
SynthWave['SYNC'][0] = 'Sync Sine'
SynthWave['SYNC'][1] = 'Sync Triangle'
SynthWave['SYNC'][2] = 'Sync Saw'
SynthWave['SYNC'][3] = 'Sync Square'
SynthWave['SYNC'][4] = 'Sync Pulse 33'
SynthWave['SYNC'][5] = 'Sync Pulse 10'
SynthWave['SYNC'][6] = 'Sync Chop Saw 1'
SynthWave['SYNC'][7] = 'Sync Chop Saw 2'
SynthWave['SYNC'][8] = 'Sync Chop Square'
SynthWave['SHAPE'] = {}
SynthWave['SHAPE'][0] = 'Shape Triangle'
SynthWave['SHAPE'][1] = 'Shape Saw'
SynthWave['SHAPE'][2] = 'Shape Square'
SynthWave['SHAPE'][3] = 'Shape Half Sine'
SynthWave['SHAPE'][4] = 'Shape Parabolic'
SynthWave['SHAPE SINE'] = {}
SynthWave['SHAPE SINE'][0] = 'Shape Sine Saw'
SynthWave['SHAPE SINE'][1] = 'Shape Sine Square'
SynthWave['SHAPE SINE'][2] = 'Shape Sine Pulse'
SynthWave['SHAPE SINE'][3] = 'Shape Sine Squeeze'
SynthWave['SHAPE SINE'][4] = 'Shape Sine Fold'
SynthWave['SHAPE SINE'][5] = 'Shape Sine ESaw'
SynthWave['SHAPE SINE'][6] = 'Shape Sine ESquare'
SynthWave['MULTI'] = {}
SynthWave['MULTI'][0] = 'Multi Saw'
SynthWave['MULTI'][1] = 'Multi Saw 8ve'
SynthWave['MULTI'][2] = 'Multi Saw 5th'
SynthWave['MULTI'][3] = 'Multi Saw 5th+'
SynthWave['MULTI'][4] = 'Multi Saw 8ve 8ve+'
SynthWave['MULTI'][5] = 'Multi Saw 8ve 5th+'
SynthWave['SUPER'] = {}
SynthWave['SUPER'][0] = 'Super Saw'
SynthWave['SUPER'][1] = 'Super Square'
SynthWave['SUPER'][2] = 'Super Organ'
SynthWave['SUPER'][3] = 'Super Saw Bright'
SynthWave['SUPER'][4] = 'Super Square Bright'
SynthWave['MISC'] = {}
SynthWave['MISC'][0] = 'Pink Noise'
SynthWave['MISC'][1] = 'Red Noise'
SynthWave['MISC'][2] = 'Bell'
SynthWave['BELLS/TINES'] = {}
SynthWave['BELLS/TINES'][0] = 'Bell'
SynthWave['BELLS/TINES'][1] = 'Bar 1'
SynthWave['BELLS/TINES'][2] = 'Bar 2'
SynthWave['BELLS/TINES'][3] = 'Tines'
SynthWave['BELLS/TINES'][4] = 'Marimba'
SynthWave['BELLS/TINES'][5] = 'Tubular Bells'
SynthWave['ACOUSTIC'] = {}
SynthWave['ACOUSTIC'][0] = 'Flute 1'
SynthWave['ACOUSTIC'][1] = 'Flute 2'
SynthWave['ACOUSTIC'][2] = 'Clarinet 1'
SynthWave['ACOUSTIC'][3] = 'Clarinet 2'
SynthWave['ACOUSTIC'][4] = 'Alto Sax'
SynthWave['ACOUSTIC'][5] = 'Tenor Sax'
SynthWave['DIGITAL'] = {}
SynthWave['DIGITAL'][ 0] = '2nd Spectra'
SynthWave['DIGITAL'][ 1] = '3rd Spectra'
SynthWave['DIGITAL'][ 2] = '4th Spectra'
SynthWave['DIGITAL'][ 3] = '5th Spectra'
SynthWave['DIGITAL'][ 4] = '6th Spectra'
SynthWave['DIGITAL'][ 5] = '7th Spectra'
SynthWave['DIGITAL'][ 6] = '8th Spectra'
SynthWave['DIGITAL'][ 7] = 'Saw Random'
SynthWave['DIGITAL'][ 8] = 'Saw Bright'
SynthWave['DIGITAL'][ 9] = 'Saw NoFund'
SynthWave['DIGITAL'][10] = 'Square Bright'
SynthWave['DIGITAL'][11] = 'Ice 1'
SynthWave['DIGITAL'][12] = 'Ice 2'
SynthWave['DIGITAL'][13] = 'Triplets'
SynthWave['ORGAN'] = {}
SynthWave['ORGAN'][0] = 'Second'
SynthWave['ORGAN'][1] = 'Third'
SynthWave['ORGAN'][2] = 'Jimmy Smith'
SynthWave['ORGAN'][3] = 'Blues'
SynthWave['ORGAN'][4] = 'Gospel'
SynthWave['ORGAN'][5] = 'Church'
SynthWave['ORGAN'][6] = 'Squabble'
SynthWave['ORGAN'][7] = 'Full Organ'
SynthWave['ORGAN'][8] = 'Full Organ+'
SynthWave['ORGAN'][9] = 'Principal'
SynthWave['KEYS'] = {}
SynthWave['KEYS'][0] = 'EPiano 1'
SynthWave['KEYS'][1] = 'EPiano 2'
SynthWave['KEYS'][2] = 'EPiano 3'
SynthWave['KEYS'][3] = 'DX 1'
SynthWave['KEYS'][4] = 'DX 2'
SynthWave['KEYS'][5] = 'Full Tines'
SynthWave['KEYS'][6] = 'AcPiano'
SynthWave['KEYS'][7] = 'Clavinet 1'
SynthWave['KEYS'][8] = 'Clavinet 2'
SynthWave['KEYS'][9] = 'Clavinet 3'

VibratoOption = {}
VibratoOption[0] = 'none'
VibratoOption[1] = 'ON'
VibratoOption[2] = 'DLY'
VibratoOption[3] = 'WHL'
VibratoOption[4] = 'A.T.'
VibratoOption[5] = 'PED'

VoicePriority = {}
VoicePriority[0] = 'no priority'
VoicePriority[1] = 'LO'
VoicePriority[2] = 'HI'

SampleOptions = {}
SampleOptions[0] = 'NATURAL'
SampleOptions[1] = 'NO DYN'
SampleOptions[2] = 'NO DYN & FAST ATK'
SampleOptions[3] = 'FAST ATK'

LFOtarget = {}
LFOtarget[0] = 'nothing'
LFOtarget[1] = 'OSC CTRL'
LFOtarget[2] = 'PITCH'
LFOtarget[3] = 'FILTER'

LFOshape = {}
LFOshape[0] = 'triangle'
LFOshape[1] = 'saw'
LFOshape[2] = 'inv saw'
LFOshape[3] = 'square'
LFOshape[4] = 'S/H'

LFOrateFracs = {}
LFOrateFracs[ 0] = '4/1'
LFOrateFracs[ 1] = '4/1T'
LFOrateFracs[ 2] = '2/1'
LFOrateFracs[ 3] = '2/1T'
LFOrateFracs[ 4] = '1/1'
LFOrateFracs[ 5] = '1/1T'
LFOrateFracs[ 6] = '1/2'
LFOrateFracs[ 7] = '1/2T'
LFOrateFracs[ 8] = '1/4'
LFOrateFracs[ 9] = '1/4T'
LFOrateFracs[10] = '1/8'
LFOrateFracs[11] = '1/8T'
LFOrateFracs[12] = '1/16'
LFOrateFracs[13] = '1/16T'
LFOrateFracs[14] = '1/32'
LFOrateFracs[15] = '1/32T'
LFOrateFracs[16] = '1/64'

ArpRateFracs = {}
ArpRateFracs[0] = '1/2'
ArpRateFracs[1] = '1/2T'
ArpRateFracs[2] = '1/4'
ArpRateFracs[3] = '1/4T'
ArpRateFracs[4] = '1/8'
ArpRateFracs[5] = '1/8T'
ArpRateFracs[6] = '1/16'
ArpRateFracs[7] = '1/16T'
ArpRateFracs[8] = '1/32'

ArpMode = {}
ArpMode[0] = 'Arp'
ArpMode[1] = 'Poly'
ArpMode[2] = 'Gate'

ArpDirection = {}
ArpDirection[0] = 'UP'
ArpDirection[1] = 'DOWN'
ArpDirection[2] = 'UP/DOWN'
ArpDirection[3] = 'RANDOM'

DelayTempoFracs = {}
DelayTempoFracs[ 0] = '1/2'
DelayTempoFracs[ 1] = '1/4D'
DelayTempoFracs[ 2] = '1/2T'
DelayTempoFracs[ 3] = '1/4S'
DelayTempoFracs[ 4] = '1/4'
DelayTempoFracs[ 5] = '1/8D'
DelayTempoFracs[ 6] = '1/4T'
DelayTempoFracs[ 7] = '1/8S'
DelayTempoFracs[ 8] = '1/8'
DelayTempoFracs[ 9] = '1/16D'
DelayTempoFracs[10] = '1/8T'
DelayTempoFracs[11] = '1/16S'
DelayTempoFracs[12] = '1/16'
DelayTempoFracs[13] = '1/16T'
DelayTempoFracs[14] = '1/32'
DelayTempoFracs[15] = '1/32T'
DelayTempoFracs[16] = '1/64'

FilterType = {}
FilterType[0] = 'LP12'
FilterType[1] = 'LP24'
FilterType[2] = 'LPM'
FilterType[3] = 'LPHP'
FilterType[4] = 'BP'
FilterType[5] = 'HP'

FilterTrack = {}
FilterTrack[0] = 'off'
FilterTrack[1] = '1/3'
FilterTrack[2] = '2/3'
FilterTrack[3] = '3/3'

PstickRng = {}
PstickRng[0] = '+/- 1'
PstickRng[1] = '+/- 2'
PstickRng[2] = '+/- 3'
PstickRng[3] = '+/- 4'
PstickRng[4] = '+/- 5'
PstickRng[5] = '+/- 7'
PstickRng[6] = '+/- 10'
PstickRng[7] = '+/- 12'
PstickRng[8] = '+2 / -12'
PstickRng[9] = '+2 / -24'

FXpianoLayerFocus = {}
FXpianoLayerFocus[0] = 'A'
FXpianoLayerFocus[1] = 'B'
FXpianoLayerFocus[2] = 'AB'

FXsynthLayerFocus = {}
FXsynthLayerFocus[0] = 'A'
FXsynthLayerFocus[1] = 'B'
FXsynthLayerFocus[2] = 'C'
FXsynthLayerFocus[4] = 'ABC'

FXmod1mode = {}
FXmod1mode[0] = 'A-PAN'
FXmod1mode[1] = 'A-PAN variation'
FXmod1mode[2] = 'TREM'
FXmod1mode[3] = 'TREM variation'
FXmod1mode[4] = 'RM'
FXmod1mode[5] = 'RM variation'
FXmod1mode[6] = 'A-WAH'
FXmod1mode[7] = 'A-WAH variation'
FXmod1mode[8] = 'WAH'
FXmod1mode[9] = 'WAH variation'
FXmod1mode[10] = 'PUMP'
FXmod1mode[11] = 'PUMP variation'

FXmod2mode = {}
FXmod2mode[0] = 'PHAS'
FXmod2mode[1] = 'PHAS variation'
FXmod2mode[2] = 'FLANG'
FXmod2mode[3] = 'FLANG variation'
FXmod2mode[4] = 'CHOR'
FXmod2mode[5] = 'CHOR variation'
FXmod2mode[6] = 'VIBE'
FXmod2mode[7] = 'VIBE variation'
FXmod2mode[8] = 'ENS'
FXmod2mode[9] = 'ENS variation'
FXmod2mode[10] = 'SPIN'
FXmod2mode[11] = 'SPIN variation'

FXcompResponse = {}
FXcompResponse[0] = 'normal'
FXcompResponse[1] = 'fast'

FXdelayMode = {}
FXdelayMode[0] = 'normal'
FXdelayMode[1] = 'analog'

FXdelayEffects = {}
FXdelayEffects[0] = 'none'
FXdelayEffects[1] = 'none'  
FXdelayEffects[2] = 'ENS'
FXdelayEffects[3] = 'ENS variation'
FXdelayEffects[4] = 'VIBE'
FXdelayEffects[5] = 'VIBE variation'
FXdelayEffects[6] = 'CHOR'
FXdelayEffects[7] = 'CHOR variation'
FXdelayEffects[8] = 'FLAM'
FXdelayEffects[9] = 'FLAM variation'
FXdelayEffects[10] = 'SPACE'
FXdelayEffects[11] = 'SPACE variation'

FXdelayFilterType = {}
FXdelayFilterType[0] = 'none'
FXdelayFilterType[1] = 'LP'
FXdelayFilterType[2] = 'HP'
FXdelayFilterType[3] = 'BP'

FXreverbType = {}
FXreverbType[ 0] = 'SPRING'
FXreverbType[ 1] = 'SPRING variation'
FXreverbType[ 2] = 'BOOTH'
FXreverbType[ 3] = 'BOOTH variation'
FXreverbType[ 4] = 'ROOM'
FXreverbType[ 5] = 'ROOM variation'
FXreverbType[ 6] = 'STAGE'
FXreverbType[ 7] = 'STAGE variation'
FXreverbType[ 8] = 'HALL'
FXreverbType[ 9] = 'HALL variation'
FXreverbType[10] = 'CATH'
FXreverbType[11] = 'CATH variation'

FXreverbDarkBright = {}
FXreverbDarkBright[0] = 'none'
FXreverbDarkBright[1] = 'DARK'
FXreverbDarkBright[2] = 'BRIGHT'

AmpEQmode = {}
AmpEQmode[0] = 'off'
AmpEQmode[1] = 'TWIN'
AmpEQmode[2] = 'TWIN variation'
AmpEQmode[3] = 'JC'
AmpEQmode[4] = 'JC variation'
AmpEQmode[5] = 'SMALL'
AmpEQmode[6] = 'SMALL variation'
AmpEQmode[7] = 'TO ROTARY'
AmpEQmode[8] = 'LP FILTER'
AmpEQmode[9] = 'HP FILTER'

SampleCategory = {}
SampleCategory[ 0] = 'Accordion/Harm'
SampleCategory[ 1] = 'Bass'
SampleCategory[ 2] = 'Brass Ensemble'
SampleCategory[ 3] = 'Brass Solo'
SampleCategory[ 4] = 'Choir'
SampleCategory[ 5] = 'Drums'
SampleCategory[ 6] = 'Effects'
SampleCategory[ 7] = 'Guitar_Plucked'
SampleCategory[ 8] = 'Mellotron'
SampleCategory[ 9] = 'Misc'
SampleCategory[10] = 'Orchestral'
SampleCategory[11] = 'Organ'
SampleCategory[12] = 'Percussion Tuned'
SampleCategory[13] = 'Piano'
SampleCategory[14] = 'Rhythmic'
SampleCategory[15] = 'Strings Analog'
SampleCategory[16] = 'Strings Ensemble'
SampleCategory[17] = 'Strings Solo'
SampleCategory[18] = 'Synth Bass'
SampleCategory[19] = 'Synth Classic'
SampleCategory[20] = 'Synth Lead'
SampleCategory[21] = 'Synth Pad'
SampleCategory[22] = 'Wind Ensemble'
SampleCategory[23] = 'Wind Solo'
SampleCategory[24] = 'User'
SampleCategory[25] = 'Undefined'

# ================================================================
def addNamesFromFile( names, filename, verbosity ):

    if not ospath.isfile( filename ):
        if verbosity >= 3:
            print( 'Warning: no file called', filename )
        return names

    if verbosity >= 2:
        print( 'Reading', filename )
    lines = open( filename, 'r' ).readlines()

    for n in range(1,len(lines)): # skip header
        words = lines[n].split(',')

        if len(words) != 2:
            print( 'Error reading', filename, ': every row should have 2 entries separated by a comma' )
            exit()

        rawval = words[0].strip()
        name = words[1].strip()

        names[rawval] = name

    return names

# ================================================================
def getNames( formatspath, verbosity ):

    pianomodels = getPianoModels()
    samplenames = getSampleNames()

    if len(formatspath) > 0:
        if not ospath.isdir( formatspath ):
            print( 'Error: no directory called', formatspath )
            exit()
        pianomodels = addNamesFromFile( pianomodels, ospath.join( formatspath, nameFilenames['piano_models'] ), verbosity )
        samplenames = addNamesFromFile( samplenames, ospath.join( formatspath, nameFilenames['sample_names'] ), verbosity )

    return pianomodels, samplenames

# ================================================================
def writeTheseNames( dictionary, filename, verbosity):

    includeHex = False

    if verbosity >= 2:
        print( 'Writing', filename )

    if includeHex:
        headers = ['ID number ', 'hex     ', 'name']
    else:
        headers = ['ID number ', 'name']

    fid = open( filename, 'w' )
    fid.write( ' , '.join(headers) )
    fid.write( '\n' )
    for key in dictionary.keys():
        if includeHex:
            row = [key, f"{int(key):x}", dictionary[key]]
        else:
            row = [key, dictionary[key]]
        fid.write( ' , '.join(row) )
        fid.write( '\n' )
    fid.close()

# ================================================================
def writeNames( outputDirectory, pianomodels, samplenames, verbosity ):

    if len(outputDirectory) > 0 and not ospath.isdir( outputDirectory ):
        print( 'Error: no directory called', outputDirectory )
        exit()

    writeTheseNames( pianomodels, ospath.join( outputDirectory, nameFilenames['piano_models'] ), verbosity )
    writeTheseNames( samplenames, ospath.join( outputDirectory, nameFilenames['sample_names'] ), verbosity )

    #  tell the user where the output files were written
    if outputDirectory in ['.', '']:
        print( 'Outputs written to current working directory' )
    else:
        print( 'Outputs written to', outputDirectory )
    
# ================================================================
#   the user is invited to add ID-to-name conversions to this list.
#
#   ns4decode will always show the ID number of a piano-model sample. 
#   If the sample is not in the list below,
#   then ns4decode shows the name as "name unknown".
#   To fix that, you may add that piano model to this list.
#   You can get the name from the Nord Stage 4 front panel display,
#   and you can get the ID number from the .csv file written by ns4decode.
#   Then you just need to add a new line to the list below, with this format:
#
#       names['10-digit ID number'] = 'name'
#
#   Remember to include the single-quotes.
#
#   Beware that if you're using a spreadsheet app to view 
#   ns4decode's output files, then the spreadsheet app might 
#   not display leading zeros in the ID number. 
#   If the ID number is less than 10 digits long, 
#   then prepend leading zeros until it's 10 digits long.
#
def getPianoModels():

    names = {}
    names['0017138523'] = 'Baby Upright XL'
    names['0027369483'] = 'EP4 Mk5 80s Lrg'
    names['0039747024'] = 'EPiano 1    Mk I'
    names['0044458426'] = 'EP6 Sparkletop Med'
    names['0046808502'] = 'MKS20 A.Piano1 Lrg'
    names['0060419209'] = 'EP5 BrightTines Med'
    names['0074155070'] = 'Hybrid EP Sml'
    names['0075048103'] = 'Amber Upright Med'
    names['0079517330'] = 'White Grand Sml'
    names['0083415724'] = 'MK80 E.Piano1 Lrg'
    names['0095105963'] = 'Romantic Upright Lrg'
    names['0107622570'] = 'EP5 Bright Tines'
    names['0108271919'] = 'Pearl Upright XL'
    names['0123111285'] = 'Felt Upright Sml'
    names['0154444019'] = 'DX7 FullTines Lrg'
    names['0183016914'] = 'French Harpsi 1D'
    names['0187935800'] = 'Baby Upright XL'
    names['0207530684'] = 'Wurlitzer 1'
    names['0212330674'] = 'MK80 E.Piano3 Lrg'
    names['0243137835'] = 'Romantic Upright Sml'
    names['0258105128'] = 'BlueSwede Med'
    names['0261125636'] = 'Bambino Upright Med'
    names['0266407908'] = 'Concert Grand1   Med'
    names['0268707526'] = 'Bambino Upright'
    names['0283188034'] = 'Bambino Upright Med'
    names['0283815828'] = 'Studio Grand 1 Sml'
    names['0287520029'] = 'Baby Upright Lrg'
    names['0288976520'] = 'EP1 Deep Timbre Sml'
    names['0307345050'] = 'Ital Harpsich 1D'
    names['0309099213'] = 'Mellow Upright Sml'
    names['0320440865'] = 'Amber Upright XL'
    names['0324042676'] = 'Amber Upright Sml'
    names['0344197536'] = 'Royal Grand 3D Med'
    names['0356988076'] = 'Black Upright Sml'
    names['0365709814'] = 'MKS20 A.Piano2 Lrg'
    names['0365904923'] = 'ConcertGrand1Amb Lrg'
    names['0375590295'] = 'Ital Harpsich 1C DoubleStr'
    names['0377618399'] = 'Royal Grand 3D Lrg'
    names['0384620219'] = 'EP3 Shallow Close Lrg'
    names['0396939640'] = 'Ballad EP1 Sml'
    names['0401488166'] = 'EP8 Nefertiti XL'
    names['0432404297'] = 'EP8 Nefertiti Lrg'
    names['0479866700'] = 'DX7 RubbaTines Lrg'
    names['0480670839'] = 'EGrand 3 Sml'
    names['0492200019'] = 'EP8 Nefertiti Lrg'
    names['0500449728'] = 'Black Upright Med'
    names['0541242237'] = 'Black Upright Sml'
    names['0550238836'] = 'Clavinet D6 6.1'
    names['0567658594'] = 'Grand Lady D   Sml'
    names['0582572064'] = 'EP8 Nefertiti Sml'
    names['0583641075'] = 'French Harpsi 1D'
    names['0621374537'] = 'MKS20 E.Piano2 Lrg'
    names['0628417658'] = 'Ballad EP1 Med'
    names['0629253435'] = 'Silver Grand Med'
    names['0657253844'] = 'Wurlitzer 1'
    names['0674127448'] = 'DX RubbaTines Lrg'
    names['0688630690'] = 'Marimba mono'
    names['0723876263'] = 'Beethoven ForteP Lrg'
    names['0732988994'] = 'Rain Piano Sml'
    names['0781352073'] = 'Saloon Upright Sml'
    names['0782409742'] = 'EP5 BrightTines XL'
    names['0804774953'] = 'Felt Upright XL'
    names['0806753372'] = 'EGrand 3 Mono Sml'
    names['0807146654'] = 'Epiano7 Mk1 Med'
    names['0815555303'] = 'Ital Harpsich 1B Long'
    names['0830333127'] = 'ConcertGrand1Amb Med'
    names['0835147299'] = 'Bright Grand XL'
    names['0842712216'] = 'Saloon Upright Lrg'
    names['0864430250'] = 'DX7 RubbaRhodes Lrg'
    names['0885618069'] = 'Mellow Upright Sml'
    names['0903899164'] = 'French Harpsi 1C'
    names['0910602750'] = 'MKS20 E.Piano1 Lrg'
    names['0926233160'] = 'Marimba'
    names['0928776492'] = 'Velvet Grand XL'
    names['0935475681'] = 'Italian Grand Med'
    names['0952591333'] = 'Felt Upright Lrg'
    names['0956797827'] = 'Wurlitzer 1'
    names['0967868505'] = 'EP6 SparkleTop'
    names['0987339280'] = 'Rain Piano Sml'
    names['1028172211'] = 'Bright Grand Sml'
    names['1028341268'] = 'Studio Grand 2 Lrg'
    names['1033297165'] = 'EP6 Sparkletop XL'
    names['1038564812'] = 'EP1 Deep Timbre Sml'
    names['1061565078'] = 'Mozart Forte Pno Lrg'
    names['1063364144'] = 'Italian Grand Sml'
    names['1092762174'] = 'EP7 Amped Tines Med'
    names['1118282659'] = 'HonkyTonkUpright Sml'
    names['1118679182'] = 'Silver Grand Sml'
    names['1119937090'] = 'EP7 Amped Tines XL'
    names['1145892321'] = 'EP1 Deep Timbre Lrg'
    names['1190348685'] = 'Velvet Grand Sml'
    names['1193296669'] = 'Wurlitzer 2 Lrg'
    names['1209279823'] = 'White Grand XL'
    names['1214451683'] = 'EPiano 2    Mk I ClosIdeal'
    names['1219887230'] = 'Wurlitzer 2 XL'
    names['1220367946'] = 'Ballad EP2 Sml'
    names['1224591879'] = 'JD800 E.Piano    Lrg'
    names['1254657053'] = 'Mellow Upright Lrg'
    names['1276180156'] = 'Baby Upright Sml'
    names['1285991176'] = 'Electric Grand 1'
    names['1308100258'] = 'Mellow Upright Lrg'
    names['1318445188'] = 'ConcertGrand1Amb Sml'
    names['1322309254'] = 'EGrand 3 Sml'
    names['1326927691'] = 'White Grand XL'
    names['1360501563'] = 'Mozart FortePno XL'
    names['1361308817'] = 'DX7 FullTines Lrg'
    names['1372604726'] = 'Bambino Upright Sml'
    names['1387158669'] = 'EP3 Shallow Close Sml'
    names['1393192103'] = 'Royal Grand 3D Med'
    names['1398343093'] = 'MK80 E.Piano2 Lrg'
    names['1421775413'] = 'Baby Upright Sml'
    names['1423349205'] = 'DigiGrand 1 Sml'
    names['1427094374'] = 'Grand Imperial Med'
    names['1427641456'] = 'Pearl Upright Sml'
    names['1428770264'] = 'Mellow Upright XL'
    names['1435873431'] = 'Silver Grand Med'
    names['1440419176'] = 'French Harpsi 1E'
    names['1468716334'] = 'Velvet Grand Lrg'
    names['1472884267'] = 'DX7 FullTines Lrg'
    names['1474457778'] = 'Wurlitzer 2 Lrg'
    names['1525153124'] = 'Bambino Upright Sml'
    names['1531800887'] = 'Romantic Upright Sml'
    names['1538961680'] = 'Queen Upright Sml'
    names['1566956853'] = 'Italian Grand Sml'
    names['1573841860'] = 'White Grand Sml'
    names['1577777003'] = 'EP8 Nefertiti Sml'
    names['1620690382'] = 'Wurlitzer 1'
    names['1639450944'] = 'Grand Imperial Sml'
    names['1649142593'] = 'Italian Grand Lrg'
    names['1681139063'] = 'EPiano 1    Mk I'
    names['1682039076'] = 'EP3 Shallow Close Sml'
    names['1683224070'] = 'Grand Imperial XL'
    names['1683313888'] = 'Grand Imperial XL'
    names['1683948862'] = 'Grand Upright Lrg'
    names['1691162699'] = 'EP5 BrightTines XL'
    names['1700164841'] = 'HonkyTonkUpright Sml'
    names['1708999631'] = 'Bambino Upright XL'
    names['1721343204'] = 'Bambino Upright Lrg'
    names['1754273483'] = 'Felt Upright Med'
    names['1754986088'] = 'EP8 Nefertiti XL'
    names['1767246786'] = 'Studio Grand 1 Med'
    names['1770716052'] = 'Soft Grand Lrg'
    names['1797778369'] = 'BlueSwede Lrg'
    names['1804484905'] = 'Mozart Forte Pno Med'
    names['1816211587'] = 'Ital Harpsich 1D Lute'
    names['1830598260'] = 'Soft Grand Med'
    names['1837054500'] = 'Bright Grand Lrg'
    names['1842562946'] = 'EPiano 4    Mk V ClosIdeal'
    names['1857221708'] = 'Felt Upright Lrg'
    names['1866648560'] = 'EP2 Ideal Timbre Sml'
    names['1884136199'] = 'White Grand Lrg'
    names['1885350104'] = 'DigiGrand 2 Sml'
    names['1891825629'] = 'Felt Upright Med'
    names['1892862558'] = 'Mozart Forte Pno Sml'
    names['1895896373'] = 'Amber Upright Lrg'
    names['1901621402'] = 'EP3 Shallow Close Lrg'
    names['1950520238'] = 'EP4 Mk5 80s Sml'
    names['1960721720'] = 'Wurlitzer 1'
    names['1985885425'] = 'Silver EP Sml'
    names['1992408978'] = 'Grand Imperial Lrg'
    names['1996984242'] = 'Black Upright Sml'
    names['2003522678'] = 'Hybrid EP Sml'
    names['2014653145'] = 'Romantic Upright Med'
    names['2055917126'] = 'Bright Grand Med'
    names['2091266687'] = 'Silver Grand Lrg'
    names['2106870304'] = 'Romantic Upright Lrg'
    names['2110246942'] = 'Italian Grand XL'
    names['2126320162'] = 'Wurlitzer 2'
    names['2127115499'] = 'Concert Grand1   Sml'
    names['2167068377'] = 'Mozart FortePno Med'
    names['2176860086'] = 'HonkyTonkUpright Med'
    names['2187749074'] = 'EP2 Ideal Timbre Lrg'
    names['2206039271'] = 'Studio Grand 2 Med'
    names['2225963895'] = 'EP7 Amped Tines'
    names['2234956184'] = 'Grand Upright Med'
    names['2246544991'] = 'BlueSwede Sml'
    names['2249755665'] = 'Italian Grand XL'
    names['2276574696'] = 'Bright Grand Med'
    names['2291657779'] = 'Felt Upright XL'
    names['2320723413'] = 'Velvet Grand Med'
    names['2338922106'] = 'French Harpsi 1B'
    names['2358210918'] = 'Queen Upright Lrg'
    names['2395608819'] = 'Velvet Grand Sml'
    names['2403555546'] = 'Black Upright Lrg'
    names['2417123209'] = 'Baby Upright Lrg'
    names['2417406771'] = 'EP8 Nefertiti    Lrg'
    names['2418304308'] = 'Velvet Grand Lrg'
    names['2419398050'] = 'Concert Grand1   Lrg'
    names['2424543327'] = 'Mozart FortePno Lrg'
    names['2468882047'] = 'White Grand Lrg'
    names['2469598719'] = 'White Grand Med'
    names['2480280970'] = 'Beethoven ForteP XL'
    names['2483469492'] = 'EGrand 3 Amped Sml'
    names['2529447489'] = 'Rain Piano Med'
    names['2529955573'] = 'Studio Grand 2 Sml'
    names['2537323517'] = 'Mellow Upright XL'
    names['2552789398'] = 'Rain Piano Lrg'
    names['2560273594'] = 'Bright Grand Lrg'
    names['2561777364'] = 'Italian Grand Med'
    names['2561884335'] = 'White Grand Med'
    names['2579339016'] = 'EP6 Sparkletop Med'
    names['2580971339'] = 'Ital Harpsich 1A Str'
    names['2599866890'] = 'DigiGrand 2 Sml'
    names['2609807865'] = 'Amber Upright Lrg'
    names['2616064581'] = 'Clavinet D6 5.0'
    names['2617700379'] = 'HonkyTonkUpright Med'
    names['2631961387'] = 'Grand Lady D   Med'
    names['2683270295'] = 'Italian Grand Lrg'
    names['2702270505'] = 'EP2 Ideal Timbre Lrg'
    names['2702331400'] = 'Studio Grand 2 Med'
    names['2715725743'] = 'Electric Grand 1'
    names['2724727384'] = 'Baby Upright Med'
    names['2740574581'] = 'Amber Upright Sml'
    names['2755985498'] = 'EP5 BrightTines Med'
    names['2776421762'] = 'Velvet Grand XL'
    names['2777765384'] = 'EP9 Stockholm Lrg'
    names['2778364498'] = 'Amber Upright Med'
    names['2820910706'] = 'Studio Grand 2 Lrg'
    names['2833309899'] = 'EP9 Stockholm XL'
    names['2846337513'] = 'Studio Grand 2 Med'
    names['2908191579'] = 'Royal Grand 3D Lrg'
    names['2915313010'] = 'Grand Imperial Lrg'
    names['2933813635'] = 'Grand Imperial Med'
    names['2943486661'] = 'Silver Grand Sml'
    names['2948607159'] = 'Silver Grand Lrg'
    names['2959875978'] = 'Mozart Forte Pno XL'
    names['2992150518'] = 'Grand Lady D   Sml'
    names['3015133176'] = 'ElectricGrand 2 CustomBld'
    names['3027868633'] = 'Royal Grand 3D Sml'
    names['3041537121'] = 'HonkyTonkUpright Lrg'
    names['3070544058'] = 'Romantic Upright Sml'
    names['3086381125'] = 'EPiano 2    Mk I ClosIdeal'
    names['3108049891'] = 'Wurlitzer 2'
    names['3131315936'] = 'Soft Grand Sml'
    names['3143115486'] = 'MKS20 A.Piano3 Lrg'
    names['3196793195'] = 'EPiano 3   Mk II'
    names['3200099108'] = 'EP5 Bright Tines CustomMod'
    names['3222034919'] = 'EP8 Nefertiti    Lrg'
    names['3238399754'] = 'French Harpsi 1F'
    names['3240251063'] = 'Grand Imperial Sml'
    names['3241560482'] = 'Saloon Upright Med'
    names['3257118660'] = 'Queen Upright Med'
    names['3268985101'] = 'Royal Grand 3D Sml'
    names['3301917550'] = 'Black Upright Med'
    names['3347740271'] = 'Beethoven ForteP Sml'
    names['3348515904'] = 'French Harpsi 1A'
    names['3359539397'] = 'Felt Upright Sml'
    names['3360563337'] = 'Studio Grand 2 Sml'
    names['3371152286'] = 'EP4 Mk5 80s Sml'
    names['3391891359'] = 'Bright Grand XM'
    names['3427112297'] = 'Baby Upright Med'
    names['3456736737'] = 'EP1 Deep Timbre Lrg'
    names['3490565097'] = 'EP6 Sparkletop XL'
    names['3491591082'] = 'Velvet Grand Med'
    names['3517763037'] = 'DX7 FullTines Lrg'
    names['3524032694'] = 'Grand Upright Sml'
    names['3536674460'] = 'MK80 A.Piano1 Lrg'
    names['3540235762'] = 'Royal Grand 3D XL'
    names['3565051066'] = 'Mellow Upright Med'
    names['3583132260'] = 'EP7 Amped Tines Med'
    names['3605163775'] = 'Pearl Upright Lrg'
    names['3630575886'] = 'EP2 Ideal Timbre Sml'
    names['3658791917'] = 'Steinway No1 XL'
    names['3664146167'] = 'EP9 Stockholm Med'
    names['3671912525'] = 'Bambino Upright Lrg'
    names['3683913124'] = 'Pearl Upright Med'
    names['3715123253'] = 'Bambino Upright XL'
    names['3721601284'] = 'Romantic Upright Med'
    names['3742164345'] = 'Studio Grand 1 Lrg'
    names['3743772052'] = 'Grand Lady D   Lrg'
    names['3765340972'] = 'Silver Grand XL'
    names['3774908408'] = 'Bright Grand Sml'
    names['3776240343'] = 'Grand Lady D   Med'
    names['3831883114'] = 'Silver Grand XL'
    names['3861827896'] = 'Amber Upright XL'
    names['3886062802'] = 'EP4 Mk5 80s Lrg'
    names['3897836162'] = 'Grand Upright XL'
    names['3900579471'] = 'DigiGrand 1 Sml'
    names['3917934714'] = 'Royal Grand 3D XL'
    names['3937346023'] = 'Studio Grand 2 XL'
    names['4023510897'] = 'Grand Lady D   Sml'
    names['4023831449'] = 'EP8 Nefertiti XL'
    names['4031544643'] = 'HonkyTonkUpright Lrg'
    names['4036159179'] = 'EGrand 3 Stereo Med'
    names['4042495255'] = 'EPiano 3   Mk II'
    names['4045524534'] = 'Ital Harpsich 1B Stri'
    names['4052530905'] = 'Black Upright Lrg'
    names['4078748675'] = 'Beethoven ForteP Med'
    names['4125378730'] = 'Mozart FortePno Sml'
    names['4125535571'] = 'EGrand 3 Mono Sml'
    names['4193287642'] = 'DX RubbaTines Lrg'
    names['4242809436'] = 'Mellow Upright Med'
    names['4256537213'] = 'Vibraphone'
    names['4266196823'] = 'Vibraphone mono'
    names['4268751563'] = 'Soft Grand XL'
    return names

# ================================================================
#   the user is invited to add ID-to-name conversions to this list.
#
#   ns4decode will always show the ID number of a synth-library sample. 
#   If the sample is not in the list below,
#   then ns4decode shows the name as "name unknown".
#   To fix that, you may add that sample to this list.
#   You can get the name from the Nord Stage 4 front panel display,
#   and you can get the ID number from the .csv file written by ns4decode.
#   Then you just need to add a new line to the list below, with this format:
#
#       names['10-digit ID number'] = 'name'
#
#   Remember to include the single-quotes.
#
#   Beware that if you're using a spreadsheet app to view 
#   ns4decode's output files, then the spreadsheet app might 
#   not display leading zeros in the ID number. 
#   If the ID number is less than 10 digits long, 
#   then prepend leading zeros until it's 10 digits long.
#
def getSampleNames():

    names = {}
    names['0003062954'] = 'Harjedalspipa_ST 4.1'
    names['0084103840'] = 'Oboe Multi_ST 4.1'
    names['0122419831'] = 'Horn Section Jazz 1_BR 4.1'
    names['0127033685'] = 'SwingStr Leg Soft Cls_ProjectSAM 4.1'
    names['0213201655'] = 'Celtic Harp_ProjectSAM 4.1'
    names['0264740869'] = 'Small Choir Fem ah Soft_CL 4.1'
    names['0431615132'] = 'Men+Boys Mm_SI 4.1'
    names['0433287959'] = 'Small Chimes_ST 4.1'
    names['0505473168'] = 'Jumbo Guitar_ST Gib 4.1'
    names['0623628089'] = 'Wine Glasses Mellotron_M400 4.1'
    names['0637067722'] = 'Harp 2_DV 4.1'
    names['0689402950'] = 'SwingStr Legato Cls_ProjectSAM 4.1'
    names['0723572944'] = 'Horn Section Funk 1_BR 4.1'
    names['0795558776'] = 'Small Choir Fem oh Soft_CL 3.0'
    names['0822855032'] = 'Swing Upright Bass_ProjectSAM 4.1'
    names['0864597029'] = 'SymphStr FastAtk Amb_ProjectSAM 4.1'
    names['0993369683'] = 'Gamba 8_ST 4.1'
    names['1060642766'] = 'Pick Bass K 63_ST 4.1'
    names['1180513908'] = 'Cathedral Organ All Stops_SR 4.1'
    names['1229946836'] = 'Angelic Choir 5 Ih_PS ste 3.0'
    names['1236835218'] = 'Rorflojt 4_ST 4.1'
    names['1282040345'] = 'SymphStr XSoft Amb_ProjectSAM 4.1'
    names['1321663019'] = 'Flute Mellotron_MKII 4.1'
    names['1330716637'] = 'Glockenspiel_ST 4.1'
    names['1343381000'] = 'French Horns_KH 4.1'
    names['1403408032'] = 'Warm Pad 1_NLA1 CL 4.1'
    names['1406648290'] = 'SwingStr Leg Soft Amb_ProjectSAM 4.1'
    names['1541413108'] = 'Orchestral Brass_BR 4.1'
    names['1591207724'] = 'Metallophone_DV 4.1'
    names['1627200818'] = 'Recorder Multi_ST 4.1'
    names['1661621168'] = 'SymphStr Sordino Amb_ProjectSAM 4.1'
    names['1671521020'] = 'Ac Guitar 12 Str_ST 4.1'
    names['1924803263'] = 'Men+Boys Oo Soft_SI 4.1'
    names['1931804452'] = 'Swing Big Band Amb_ProjectSAM 4.1'
    names['1975923359'] = 'Small Choir Male oh Soft_CL 3.0'
    names['1990208678'] = 'Banjo 1_DV 4.1'
    names['2046449085'] = 'Swing Upright Bass Slap_ProjectSAM 4.1'
    names['2180199104'] = 'SymphStr Sordino Cls_ProjectSAM 4.1'
    names['2278298181'] = 'Female voices ah_SR 4.1'
    names['2300957938'] = 'Nylon Guitar 2_ST 4.1'
    names['2324211628'] = 'Flute Multi_ST 4.1'
    names['2584396166'] = 'Cathedral Organ_SR 4.1'
    names['2610712832'] = 'Clarinet Multi_ST 4.1'
    names['2716509210'] = 'Finger Bass ALB_ST 4.1'
    names['2726408844'] = 'Ac Guitar Finger_ST Mart 4.1'
    names['2748011711'] = 'BrassSection Double 2_CL 4.1'
    names['2768936524'] = 'Strings Multi FastAtk_ST 4.1'
    names['2785224982'] = 'Horns+Winds_SR 4.1'
    names['2841415599'] = 'Eminent 310 Str L 8+4_PH 4.13'
    names['2843131652'] = 'Trumpet_ST 4.1'
    names['2906811051'] = 'Swing Big Band Soft Amb_ProjectSAM 4.1'
    names['2943699334'] = 'SymphStr Spicc Amb_ProjectSAM 4.1'
    names['3007268156'] = 'Angelic Choir 4 Oh_PS 3.0'
    names['3040922269'] = 'Trumpets Legato_KH 4.1'
    names['3044605558'] = 'Small Choir Fem oh Soft_CL 4.1'
    names['3055420235'] = 'Six-String Bass VI_ST 4.1'
    names['3068103786'] = 'Tubular Bells_ST 4.1'
    names['3071849432'] = 'Indian Santoor_PS 4.1'
    names['3073805452'] = 'Harp 1_ST 4.1'
    names['3096957617'] = 'Finger Bass P 58_ST 4.1'
    names['3100227591'] = 'Muted Brass Legato_SR 4.1'
    names['3113519129'] = 'Brass Section Pop 3_BR 4.1'
    names['3129717527'] = 'English Horn_ST 4.1'
    names['3165533795'] = 'Principal 8_ST 4.1'
    names['3253818411'] = 'Orchestral Brass Soft_BR 4.1'
    names['3257696976'] = 'Upright Bass Finger_BS 4.1'
    names['3262471627'] = 'SwingStr Stacc Amb_ProjectSAM 4.1'
    names['3267790505'] = 'Pop Strings_KG 4.1'
    names['3324987194'] = 'Angelic Choir 5 Uh_PS 3.0'
    names['3349339141'] = 'Fretless Bass MM_ST 4.1'
    names['3353322281'] = 'Strings+Winds_SR 4.1'
    names['3381366498'] = 'SymphStr XSoft Cls_ProjectSAM 4.1'
    names['3421855808'] = 'SwingStr Legato Amb_ProjectSAM 4.1'
    names['3491020436'] = 'Soft Strings Legato_SR 3.0'
    names['3564918607'] = 'SymphStr Leg Soft Amb_ProjectSAM 4.1'
    names['3646567370'] = 'Plattenglocken_ST 4.1'
    names['3683049632'] = 'Jazz Guitar_ST 4.1'
    names['3697708172'] = 'Swing Big Band Soft Cls_ProjectSAM 4.1'
    names['3846026064'] = 'SymphStr Legato Amb_ProjectSAM 4.1'
    names['3852669807'] = 'All Winds Legato_SR 4.1'
    names['3898851004'] = 'SwingStr Stacc Cls_ProjectSAM 4.1'
    names['3916303921'] = 'OrchStrings Legato_KH 4.1'
    names['3918615442'] = 'Female Solo Voice Chamberlin_M25 4.1'
    names['3928916420'] = 'Kalimba_KG 4.1'
    names['4045693000'] = 'Indian Surmantal_PS 4.1'
    names['4116339389'] = '3-Flutes Legato_SO 4.1'
    names['4151178886'] = 'E Guitar S 62_ST 4.1'
    names['4196852178'] = '3 Violins Mellotron_MKII 4.1'
    names['4280239005'] = 'ELKA Rhapsodie Str1_ 4.13'
    names['4288907252'] = 'SymphStr Pizz Amb_ProjectSAM 4.1'
    return names

